Config class

A collection of properties used to specify custom behavior of the GoogleFonts library.

Constructors

Config()

Properties

allowRuntimeFetching bool
Whether or not the GoogleFonts library can make requests to fonts.google.com to retrieve font files.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited