config property
Configuration for the GoogleFonts library.
Use this to define custom behavior of the GoogleFonts library in your app.
For example, if you do not want the GoogleFonts library to make any HTTP
requests for fonts, add the following snippet to your app's main method.
GoogleFonts.config.allowRuntimeFetching = false;
Implementation
static final Config config = Config();